Breezy (``brz``) is a decentralized revision control system, designed to be
easy for developers and end users alike.

By default, Breezy provides support for both the `Bazaar
<https://www.bazaar-vcs.org>`_ and `Git <https://www.git-scm.com/>`_ file
formats.

You can install from source by following the instructions in the INSTALL file.
At the moment of writing there are no binary packages available.

To learn how to use Breezy, see the official documentation in the `doc`
directory or refer to the Bazaar documentation at
<https://www.breezy-vcs.org/doc/en/>.

Breezy is Free Software, and is released under the GNU General Public License,
version 2 or later.

Breezy is a friendly fork of the Bazaar (``bzr``) project, hosted on
http://bazaar.canonical.com/. It is backwards compatibility with
Bazaar's disk format and protocols. One of the key differences with
Bazaar is that Breezy also runs on Python 3.3 and later, in addition to
Python 2.7.

Breezy highlights
=================

Breezy directly supports both central version control (like cvs/svn) and
distributed version control (like git/hg). Developers can organize their
workspace in whichever way they want on a per project basis including:

* checkouts (like svn)
* feature branches (like hg)
* shared working tree (like git).

It also directly supports and encourages a large number of development best
practices like refactoring and pre-commit regression testing. Users can
choose between our command line tool and our cross-platform GUI application.
For further details, see our website.

Feedback
========

If you encounter any problems with Breezy, need help understanding it, or would
like to offer suggestions or feedback, please get in touch with us:

* Ask a question through our web support interface, at
  https://answers.launchpad.net/brz/

* Report bugs at https://bugs.launchpad.net/brz/+filebug

* Write to the mailing list at bazaar@lists.canonical.com
  You can join the list at <https://lists.ubuntu.com/mailman/listinfo/bazaar>.
  You don't need to subscribe to post, but your first post will be held
  briefly for manual moderation.

  Please mention that you are using Breezy rather than Bazaar.

* Talk to us in irc://irc.freenode.net/bzr

  Please mention that you are using Breezy rather than Bazaar.

Our mission is to make a version control tool that developers LOVE to use
and that casual contributors feel confident with. Please let us know how
we're going.

The Breezy Team
